@@ -90,12 +90,8 @@ ack_clear_prompt_cb(GnomeAppBar * bar, gpointer data)
   g_print("Clearing prompt (ack)\n");
 #endif
 
-  gtk_signal_disconnect_by_func(GTK_OBJECT(bar), 
-				GTK_SIGNAL_FUNC(ack_cb),
-				data);
-  gtk_signal_disconnect_by_func(GTK_OBJECT(bar), 
-				GTK_SIGNAL_FUNC(ack_clear_prompt_cb),
-				data);
+  g_signal_handlers_disconnect_by_func(bar, ack_cb, data);
+  g_signal_handlers_disconnect_by_func(bar, ack_clear_prompt_cb, data);
 }
 
 static void gnome_app_message_bar (GnomeApp * app, const gchar * message)
@@ -104,10 +100,8 @@ static void gnome_app_message_bar (GnomeApp * app, const gchar * message)
   gnome_appbar_set_prompt(GNOME_APPBAR(app->statusbar), prompt, FALSE);
   gnome_app_activate_statusbar(app);
   g_free(prompt);
-  gtk_signal_connect(GTK_OBJECT(app->statusbar), "user_response",
-		     GTK_SIGNAL_FUNC(ack_cb), NULL);
-  gtk_signal_connect(GTK_OBJECT(app->statusbar), "clear_prompt",
-		     GTK_SIGNAL_FUNC(ack_clear_prompt_cb), NULL);
+  g_signal_connect(app->statusbar, "user_response", G_CALLBACK(ack_cb), NULL);
+  g_signal_connect(app->statusbar, "clear_prompt", G_CALLBACK(ack_clear_prompt_cb), NULL);
 }
 
 
@@ -236,7 +230,7 @@ remove_message_timeout (MessageInfo * mi)
   GDK_THREADS_ENTER ();	
 	
   gnome_appbar_refresh(GNOME_APPBAR(mi->app->statusbar));
-  gtk_signal_disconnect(GTK_OBJECT(mi->app), mi->handlerid);
+  g_signal_handler_disconnect(mi->app, mi->handlerid);
   g_free ( mi );
 
   GDK_THREADS_LEAVE ();
@@ -291,10 +285,10 @@ gnome_app_flash (GnomeApp * app, const gchar * flash)
 			mi );
     
     mi->handlerid = 
-      gtk_signal_connect ( GTK_OBJECT(app),
-			   "destroy",
-			   GTK_SIGNAL_FUNC(remove_timeout_cb),
-			   mi );
+      g_signal_connect (G_OBJECT(app),
+			"destroy",
+			G_CALLBACK(remove_timeout_cb),
+			mi);
 
     mi->app       = app;
   }   
@@ -319,12 +313,12 @@ bar_reply_cb(GnomeAppBar * ab, ReplyInfo * ri)
   g_print("Got reply: \"%s\"\n", response);
 #endif
 
-  if ( (g_strcasecmp(_("y"), response) == 0) || 
-       (g_strcasecmp(_("yes"), response) == 0) ) {
+  if ( (g_ascii_strcasecmp(_("y"), response) == 0) || 
+       (g_ascii_strcasecmp(_("yes"), response) == 0) ) {
     (* (ri->callback)) (GNOME_YES, ri->data);
   }
-  else if ( (g_strcasecmp(_("n"), response) == 0) || 
-	    (g_strcasecmp(_("no"), response) == 0) ) {
+  else if ( (g_ascii_strcasecmp(_("n"), response) == 0) || 
+	    (g_ascii_strcasecmp(_("no"), response) == 0) ) {
     (* (ri->callback)) (GNOME_NO, ri->data);
   }
   else {
@@ -346,12 +340,8 @@ reply_clear_prompt_cb(GnomeAppBar * ab, ReplyInfo * ri)
 #ifdef GNOME_ENABLE_DEBUG
   g_print("Clear prompt callback (reply)\n");
 #endif
-  gtk_signal_disconnect_by_func(GTK_OBJECT(ab), 
-				GTK_SIGNAL_FUNC(bar_reply_cb),
-				ri);
-  gtk_signal_disconnect_by_func(GTK_OBJECT(ab), 
-				GTK_SIGNAL_FUNC(reply_clear_prompt_cb),
-				ri);
+  g_signal_handlers_disconnect_by_func(ab, bar_reply_cb, ri);
+  g_signal_handlers_disconnect_by_func(ab, reply_clear_prompt_cb, ri);
   g_free(ri);
 }
 
@@ -857,7 +847,7 @@ void gnome_app_set_progress (GnomeAppProgressKey key, gdouble percent)
   g_return_if_fail ( key != NULL );  
 
   if (real_key->bar) {
-    gtk_progress_bar_update ( GTK_PROGRESS_BAR(real_key->bar), percent );
+    gtk_progress_bar_set_fraction ( GTK_PROGRESS_BAR(real_key->bar), percent );
   }
   else {
     gnome_appbar_set_progress_percentage ( GNOME_APPBAR(real_key->widget), percent );
@@ -887,7 +877,7 @@ void gnome_app_progress_done (GnomeAppProgressKey key)
 
   progress_timeout_remove((ProgressKeyReal *)key);
 
-  gtk_signal_disconnect(GTK_OBJECT(real_key->app), real_key->handler_id);
+  g_signal_handler_disconnect(real_key->app, real_key->handler_id);
 
   if (real_key->bar) { /* It's a dialog */
     if (real_key->widget) gnome_dialog_close(GNOME_DIALOG(real_key->widget));
