@@ -208,11 +208,8 @@ gnome_app_instance_init (GnomeApp *app)
 	gtk_box_pack_start (GTK_BOX (app->vbox), app->dock,
 			    TRUE, TRUE, 0);
 
-	gtk_signal_connect (GTK_OBJECT (app->dock),
-			    "layout_changed",
-			    GTK_SIGNAL_FUNC (layout_changed),
-			    (gpointer) app);
-
+	g_signal_connect (app->dock, "layout_changed", G_CALLBACK (layout_changed), app);
+	
 	app->enable_layout_config = TRUE;
 
 	g_object_get (G_OBJECT (gnome_program_get ()),
@@ -359,7 +356,7 @@ gnome_app_destroy (GtkObject *object)
 	}
 
 	if (app->layout != NULL) {
-		gtk_object_unref (GTK_OBJECT (app->layout));
+		g_object_unref (app->layout);
 		app->layout = NULL;
 	}
 
@@ -400,9 +397,7 @@ contents_parent_set (GtkWidget *widget, GtkWidget *previous_parent, gpointer dat
 
 	g_assert (previous_parent == app->dock);
 
-	gtk_signal_disconnect_by_func (GTK_OBJECT (widget),
-				       GTK_SIGNAL_FUNC (contents_parent_set),
-				       data);
+	g_signal_handlers_disconnect_by_func (widget, contents_parent_set, data);
 
 	app->contents = NULL;
 }
@@ -433,9 +428,9 @@ gnome_app_set_contents (GnomeApp *app, GtkWidget *contents)
 
 	if (new_contents == contents && new_contents != app->contents) {
 		gtk_widget_show (new_contents);
-		gtk_signal_connect (GTK_OBJECT (new_contents), "parent_set",
-				    GTK_SIGNAL_FUNC (contents_parent_set),
-				    app);
+		g_signal_connect (G_OBJECT (new_contents), "parent_set",
+				  G_CALLBACK (contents_parent_set),
+				  app);
 
 		app->contents = new_contents;
 	}
@@ -466,7 +461,7 @@ gnome_app_set_menus (GnomeApp *app, GtkMenuBar *menubar)
 	behavior = (BONOBO_DOCK_ITEM_BEH_EXCLUSIVE
 		    | BONOBO_DOCK_ITEM_BEH_NEVER_VERTICAL);
 	
-	if ( ! gnome_gconf_get_bool ("/desktop/gnome/interface/menubar-detachable"))
+	if ( ! gnome_gconf_get_bool ("/desktop/gnome/interface/menubar_detachable"))
 		behavior |= BONOBO_DOCK_ITEM_BEH_LOCKED;
 
 	dock_item = bonobo_dock_item_new (GNOME_APP_MENUBAR_NAME,
@@ -474,27 +469,9 @@ gnome_app_set_menus (GnomeApp *app, GtkMenuBar *menubar)
 	gtk_container_add (GTK_CONTAINER (dock_item), GTK_WIDGET (menubar));
 
 	app->menubar = GTK_WIDGET (menubar);
-
-	/* To have menubar relief agree with the toolbar (and have the relief
-	 * outside of smaller handles), substitute the dock item's relief for
-	 * the menubar's relief, but don't change the size of the menubar in
-	 * the process. */
-#ifdef FIXME
-	gtk_menu_bar_set_shadow_type (GTK_MENU_BAR (app->menubar),
-				      GTK_SHADOW_NONE);
-#endif
-	if (gnome_gconf_get_bool ("/desktop/gnome/interface/menubar-relief")) {
-		guint border_width;
-		
-		gtk_container_set_border_width (GTK_CONTAINER (dock_item), 2);
-		border_width = GTK_CONTAINER (app->menubar)->border_width;
-		if (border_width >= 2)
-			border_width -= 2;
-		gtk_container_set_border_width (GTK_CONTAINER (app->menubar),
-						border_width);
-	} else
-		bonobo_dock_item_set_shadow_type (BONOBO_DOCK_ITEM (dock_item),
-						 GTK_SHADOW_NONE);
+	
+	bonobo_dock_item_set_shadow_type (BONOBO_DOCK_ITEM (dock_item),
+					  GTK_SHADOW_NONE);
 
 	if (app->layout != NULL)
 		bonobo_dock_layout_add_item (app->layout,
@@ -510,7 +487,7 @@ gnome_app_set_menus (GnomeApp *app, GtkMenuBar *menubar)
 	gtk_widget_show (GTK_WIDGET (menubar));
 	gtk_widget_show (GTK_WIDGET (dock_item));
 
-	ag = gtk_object_get_data(GTK_OBJECT(app), "GtkAccelGroup");
+	ag = g_object_get_data(G_OBJECT(app), "GtkAccelGroup");
 	if (ag && !g_slist_find(gtk_accel_groups_from_object (G_OBJECT (app)), ag))
 	        gtk_window_add_accel_group(GTK_WINDOW(app), ag);
 }
@@ -638,7 +615,7 @@ gnome_app_add_toolbar (GnomeApp *app,
 	gtk_widget_show (GTK_WIDGET (toolbar));
 	gtk_widget_show (GTK_WIDGET (dock_item));
 
-	ag = gtk_object_get_data(GTK_OBJECT(app), "GtkAccelGroup");
+	ag = g_object_get_data(G_OBJECT(app), "GtkAccelGroup");
 	if (ag && !g_slist_find(gtk_accel_groups_from_object (G_OBJECT (app)), ag))
 	        gtk_window_add_accel_group(GTK_WINDOW(app), ag);
 }
@@ -663,7 +640,7 @@ gnome_app_set_toolbar (GnomeApp *app,
 	   requirement.  We only do this for backwards compatibility.  */
 	behavior = BONOBO_DOCK_ITEM_BEH_EXCLUSIVE;
 	
-	if ( ! gnome_gconf_get_bool ("/desktop/gnome/interface/toolbar-detachable"))
+	if ( ! gnome_gconf_get_bool ("/desktop/gnome/interface/toolbar_detachable"))
 		behavior |= BONOBO_DOCK_ITEM_BEH_LOCKED;
 	
 	gnome_app_add_toolbar (app, toolbar,
@@ -712,9 +689,7 @@ gnome_app_add_dock_item (GnomeApp *app,
 				     offset,
 				     FALSE);
 
-	gtk_signal_emit_by_name (GTK_OBJECT (app->dock),
-				 "layout_changed",
-				 (gpointer) app);
+	g_signal_emit_by_name (app->dock, "layout_changed", app);
 }
 
 /**
